@@ -11,20 +11,24 @@
 //!
 //! # Examples
 //!
+//! ## Run PSO
+//!
 //! ```rust
 //! use pso_rs::*;
 //!
-//! // define objective function (Rosenbrock)
-//! fn objective_function(p: &Particle,
-//!                 _flat_dim: usize,
-//!                 _dimensions: &Vec<usize>)
-//!     -> f64 {
-//!     // x = p[0], y = p[1]
-//!     (1.0-p[0]).powf(2.0) + 100.0
-//!         * ((p[1]-p[0]).powf(2.0)).powf(2.0)
+//! // define objective function (d-dimensional Rosenbrock)
+//! fn objective_function(
+//!     p: &Particle,
+//!     _flat_dim: usize,
+//!     dimensions: &Vec<usize>
+//! ) -> f64 {
+//!     (0..dimensions[0] - 1).map(|i| {
+//!         100.0 * ((p[i+1]-p[i]).powf(2.0)).powf(2.0)
+//!             + (1.0-p[i]).powf(2.0)
+//!     }).sum()
 //! }
 //!
-//! // define a termination condition
+//! // define a termination condition (optional)
 //! fn terminate(f_best: f64) -> bool {
 //!     f_best - (0.0) < 1e-4
 //! }
@@ -40,9 +44,48 @@
 //!     ..Config::default()
 //! };
 //!
-//! let pso = pso_rs::run(config,
-//!                 objective_function,
-//!                 Some(terminate)).unwrap();
+//! let pso = pso_rs::run(
+//!     config,
+//!     objective_function,
+//!     Some(terminate)
+//! ).unwrap();
+//!     
+//! let model = pso.model;
+//! println!("Model: {:?} ", model.get_f_best());
+//! ```
+//!
+//! ## Initialize PSO for later execution
+//!
+//! ```rust
+//! use pso_rs::*;
+//!
+//! // define objective function (d-dimensional Rosenbrock)
+//! fn objective_function(
+//!     p: &Particle,
+//!     _flat_dim: usize,
+//!     dimensions: &Vec<usize>
+//! ) -> f64 {
+//!     (0..dimensions[0] - 1).map(|i| {
+//!         100.0 * ((p[i+1]-p[i]).powf(2.0)).powf(2.0)
+//!             + (1.0-p[i]).powf(2.0)
+//!     }).sum()
+//! }
+//!
+//!
+//! let config = Config {
+//!     dimensions: vec![2],
+//!     bounds: (-5.0, 10.0),
+//!     t_max: 10000,
+//!     ..Config::default()
+//! };
+//!
+//! let mut pso = pso_rs::init(
+//!     config,
+//!     objective_function
+//! ).unwrap();
+//!
+//! // run PSO with no termination condition
+//! pso.run(|_| false);
 //!     
 //! let model = pso.model;
 //! println!("Model: {:?} ", model.get_f_best());
@@ -58,9 +101,10 @@
 //! ```rust
 //! use pso_rs::*;
 //!
-//! fn reshape(particle: &Particle,
-//!         particle_dims: &Vec<usize>)
-//!     -> Vec<Vec<f64>> {
+//! fn reshape(
+//!     particle: &Particle,
+//!     particle_dims: &Vec<usize>
+//! ) -> Vec<Vec<f64>> {
 //!     let mut reshaped_cluster = vec![];
 //!     let mut i = 0;
 //!     for _ in 0..particle_dims[0] {
@@ -75,10 +119,11 @@
 //! }
 //!
 //! // used in the objective function
-//! fn objective_function(p: &Particle,
-//!                 _flat_dim: usize,
-//!                 dimensions: &Vec<usize>)
-//!     -> f64 {
+//! fn objective_function(
+//!     p: &Particle,
+//!     _flat_dim: usize,
+//!     dimensions: &Vec<usize>
+//! ) -> f64 {
 //!     let _reshaped_particle = reshape(p, dimensions);
 //!     /* Do stuff */
 //!     0.0
@@ -90,9 +135,12 @@
 //!     t_max: 1,
 //!     ..Config::default()
 //! };
-//! let pso = pso_rs::run(config,
-//!                     objective_function,
-//!                     None).unwrap();
+//!
+//! let pso = pso_rs::run(
+//!     config,
+//!     objective_function,
+//!     None
+//! ).unwrap();
 //!
 //! // somewhere in main(), after running PSO as in the example:
 //! println!(
@@ -121,8 +169,7 @@ pub fn run(
     obj_f: fn(&Particle, usize, &Vec<usize>) -> f64,
     terminate_f: Option<fn(f64) -> bool>,
 ) -> Result<PSO, Box<dyn Error>> {
-    let model = Model::new(config, obj_f);
-    let mut pso = PSO::new(model);
+    let mut pso = init(config, obj_f).unwrap();
     let term_condition = match terminate_f {
         Some(terminate_f) => terminate_f,
         None => |_| false,
@@ -131,6 +178,18 @@ pub fn run(
     Ok(pso)
 }
 
+/// Initializes and returns a PSO instance without running the optimization process
+///
+/// Useful for initializing an instance for running at a later time
+pub fn init(
+    config: Config,
+    obj_f: fn(&Particle, usize, &Vec<usize>) -> f64,
+) -> Result<PSO, Box<dyn Error>> {
+    let model = Model::new(config, obj_f);
+    let pso = PSO::new(model);
+    Ok(pso)
+}
+
 #[cfg(test)]
 mod tests {
 
